@@ -341,7 +341,12 @@ def wrap(content: str, config: argparse.Namespace) -> str:
 def generate_multiple_txt(
     chapters: list[Chapter], config: argparse.Namespace
 ) -> None:
-    """Write the extracted book into multiple txt file."""
+    """Write the extracted book into multiple txt file.
+
+    Args:
+        chapters (list): A list of Chapter.
+        config (argparse.Namespace): config from args or file
+    """
     for chapter in chapters:
         content = str(chapter)
         if config.txt_replace:
